Versions
========

* 1.2 (2015-02-04)
    * Partial support for very old versions of CASAVA

* 1.1 (2015-01-27)
    * Scripts are renamed (now they all have 'iu-' prefix).
    * Minor enhancements.

* 1.0 (2015-01-24)
    * First stable release.
